@@ -9,9 +9,9 @@
 #'
 #' @param x A data frame.
 #' @param n Number of clusters used for supervised cluster methods. If `NULL`,
-#' the number of clusters to extract is determined by calling [n_clusters()]. Note
-#' that this argument does not apply for unsupervised clustering methods like
-#' `dbscan`, `hdbscan`, `mixture`, `pvclust`, or `pamk`.
+#' the number of clusters to extract is determined by calling [`n_clusters()`].
+#' Note that this argument does not apply for unsupervised clustering methods
+#' like `dbscan`, `hdbscan`, `mixture`, `pvclust`, or `pamk`.
 #' @param method Method for computing the cluster analysis. Can be `"kmeans"`
 #'   (default; k-means using `kmeans()`), `"hkmeans"` (hierarchical k-means
 #'   using `factoextra::hkmeans()`), `pam` (K-Medoids using `cluster::pam()`),
@@ -25,19 +25,19 @@
 #'   distances (e.g., when `method = "hclust"` for hierarchical clustering. For
 #'   other methods, such as `"kmeans"`, this argument will be ignored). Must be
 #'   one of `"euclidean"`, `"maximum"`, `"manhattan"`, `"canberra"`, `"binary"`
-#'   or `"minkowski"`. See [dist()] and `pvclust::pvclust()` for more
+#'   or `"minkowski"`. See [`dist()`] and `pvclust::pvclust()` for more
 #'   information.
 #' @param hclust_method Agglomeration method to be used when `method = "hclust"`
 #'   or `method = "hkmeans"` (for hierarchical clustering). This should be one
 #'   of `"ward"`, `"ward.D2"`, `"single"`, `"complete"`, `"average"`,
 #'   `"mcquitty"`, `"median"` or `"centroid"`. Default is `"complete"` (see
-#'   [hclust()]).
+#'   [`hclust()`]).
 #' @param kmeans_method Algorithm used for calculating kmeans cluster. Only applies,
 #'   if `method = "kmeans"`. May be one of `"Hartigan-Wong"` (default),
-#'   `"Lloyd"` (used by SPSS), or `"MacQueen"`. See [kmeans()] for details on
+#'   `"Lloyd"` (used by SPSS), or `"MacQueen"`. See [`kmeans()`] for details on
 #'   this argument.
 #' @param iterations The number of replications.
-#' @param dbscan_eps The 'eps' argument for DBSCAN method. See [n_clusters_dbscan()].
+#' @param dbscan_eps The `eps` argument for DBSCAN method. See [`n_clusters_dbscan()`].
 #'
 #' @inheritParams equivalence_test.lm
 #' @inheritParams n_clusters
@@ -59,11 +59,11 @@
 #' Clusters classification can be obtained via `print(x, newdata = NULL, ...)`.
 #'
 #' @seealso
-#' - [n_clusters()] to determine the number of clusters to extract.
-#' - [cluster_discrimination()] to determine the accuracy of cluster group
-#' classification via linear discriminant analysis (LDA).
-#' - [check_clusterstructure()] to check suitability of data
-#' for clustering.
+#' - [`n_clusters()`] to determine the number of clusters to extract.
+#' - [`cluster_discrimination()`] to determine the accuracy of cluster group
+#'   classification via linear discriminant analysis (LDA).
+#' - [`performance::check_clusterstructure()`] to check suitability of data
+#'   for clustering.
 #' - https://www.datanovia.com/en/lessons/
 #'
 #' @examples
@@ -145,7 +145,9 @@ cluster_analysis <- function(x,
   # check if we have a correlation/covariance or distance matrix?
   if (nrow(x) == ncol(x) && identical(round(x[lower.tri(x)], 10), round(x[upper.tri(x)], 10))) {
     ## TODO: special handling
-    warning(insight::format_message("Input data seems to be a correlation, covariance or similar matrix."), call. = FALSE)
+    insight::format_warning(
+      "Input data seems to be a correlation, covariance or similar matrix."
+    )
   }
 
   # Preprocess data
@@ -158,13 +160,20 @@ cluster_analysis <- function(x,
         nc <- n_clusters(data, standardize = FALSE, ...)
         n <- attributes(nc)$n
         if (verbose) {
-          insight::print_color(sprintf("Using solution with %i clusters, supported by %i out of %i methods.\n", n, max(summary(nc)$n_Methods), sum(summary(nc)$n_Methods)), "blue")
+          insight::print_color(sprintf(
+            "Using solution with %i clusters, supported by %i out of %i methods.\n",
+            n,
+            max(summary(nc)$n_Methods),
+            sum(summary(nc)$n_Methods)
+          ), "blue")
         }
         n
       },
       error = function(e) {
         if (isTRUE(verbose)) {
-          stop(insight::format_message("Could not extract number of cluster. Please provide argument 'n'."), call. = FALSE)
+          insight::format_error(
+            "Could not extract number of clusters. Please provide argument `n`."
+          )
         }
         2
       }
@@ -179,13 +188,21 @@ cluster_analysis <- function(x,
   if (any(method == "kmeans")) {
     rez <- .cluster_analysis_kmeans(data, n = n, kmeans_method = kmeans_method, iterations = iterations, ...)
   } else if (any(method %in% c("hkmeans"))) {
-    rez <- .cluster_analysis_hkmeans(data, n = n, kmeans_method = kmeans_method, hclust_method = hclust_method, iterations = iterations, ...)
+    rez <- .cluster_analysis_hkmeans(
+      data,
+      n = n, kmeans_method = kmeans_method, hclust_method = hclust_method,
+      iterations = iterations, ...
+    )
   } else if (any(method %in% c("pam"))) {
     rez <- .cluster_analysis_pam(data, n = n, distance_method = distance_method, ...)
   } else if (any(method %in% c("pamk"))) {
     rez <- .cluster_analysis_pamk(data, distance_method = distance_method, ...)
   } else if (any(method %in% c("hclust"))) {
-    rez <- .cluster_analysis_hclust(data, n = n, distance_method = distance_method, hclust_method = hclust_method, iterations = iterations, ...)
+    rez <- .cluster_analysis_hclust(
+      data,
+      n = n, distance_method = distance_method, hclust_method = hclust_method,
+      iterations = iterations, ...
+    )
   } else if (any(method == "dbscan")) {
     rez <- .cluster_analysis_dbscan(data, dbscan_eps = dbscan_eps, ...)
   } else if (any(method == "hdbscan")) {
@@ -193,7 +210,7 @@ cluster_analysis <- function(x,
   } else if (any(method %in% c("mixture", "mclust"))) {
     rez <- .cluster_analysis_mixture(data, n = n, ...)
   } else {
-    stop("Did not find 'method' argument. Could be misspecified.")
+    insight::format_error("Did not find `method` argument. Could be misspecified.")
   }
 
   # Assign clusters to observations
@@ -227,13 +244,23 @@ cluster_analysis <- function(x,
   list(model = model, clusters = model$cluster)
 }
 
+
 #' @keywords internal
-.cluster_analysis_hkmeans <- function(data, n = 2, kmeans_method = "Hartigan-Wong", hclust_method = "complete", iterations = 100, ...) {
+.cluster_analysis_hkmeans <- function(data,
+                                      n = 2,
+                                      kmeans_method = "Hartigan-Wong",
+                                      hclust_method = "complete",
+                                      iterations = 100,
+                                      ...) {
   insight::check_if_installed("factoextra")
-  model <- factoextra::hkmeans(data, k = n, km.algorithm = kmeans_method, iter.max = iterations, hc.method = hclust_method, ...)
+  model <- factoextra::hkmeans(data,
+    k = n, km.algorithm = kmeans_method,
+    iter.max = iterations, hc.method = hclust_method, ...
+  )
   list(model = model, clusters = model$cluster)
 }
 
+
 #' @keywords internal
 .cluster_analysis_pam <- function(data = NULL, n = 2, distance_method = "euclidean", ...) {
   insight::check_if_installed("cluster")
@@ -243,6 +270,7 @@ cluster_analysis <- function(x,
   list(model = model, clusters = model$clustering)
 }
 
+
 #' @keywords internal
 .cluster_analysis_pamk <- function(data = NULL, distance_method = "euclidean", pamk_method = "ch", ...) {
   insight::check_if_installed("fpc")
@@ -252,14 +280,29 @@ cluster_analysis <- function(x,
   list(model = model$pamobject, clusters = model$pamobject$clustering)
 }
 
+
 #' @keywords internal
-.cluster_analysis_hclust <- function(data, n = 2, distance_method = "euclidean", hclust_method = "complete", iterations = 100, ...) {
+.cluster_analysis_hclust <- function(data,
+                                     n = 2,
+                                     distance_method = "euclidean",
+                                     hclust_method = "complete",
+                                     iterations = 100,
+                                     ...) {
   if (is.null(n)) {
-    rez <- n_clusters_hclust(data, preprocess = FALSE, distance_method = distance_method, hclust_method = hclust_method, iterations = iterations, ...)
+    rez <- n_clusters_hclust(
+      data,
+      preprocess = FALSE,
+      distance_method = distance_method,
+      hclust_method = hclust_method,
+      iterations = iterations,
+      ...
+    )
     out <- list(model = attributes(rez)$model, clusters = rez$Cluster)
   } else {
     if (distance_method %in% c("correlation", "uncentered", "abscor")) {
-      warning(paste0("method '", distance_method, "' not supported by regular hclust(). Please specify another one or set n = NULL to use pvclust."))
+      insight::format_warning(paste0(
+        "Method `", distance_method, "` not supported by regular `hclust()`. Please specify another one or set `n = NULL` to use pvclust."
+      ))
     }
     dist <- dist(data, method = distance_method, ...)
     model <- stats::hclust(dist, method = hclust_method, ...)
@@ -268,6 +311,7 @@ cluster_analysis <- function(x,
   out
 }
 
+
 #' @keywords internal
 .cluster_analysis_dbscan <- function(data = NULL, dbscan_eps = 0.15, min_size = 0.05, borderPoints = FALSE, ...) {
   insight::check_if_installed("dbscan")
@@ -321,7 +365,7 @@ print.cluster_analysis <- function(x, ...) {
   cat("\n")
   print(attributes(x)$performance)
 
-  insight::print_color("\n# You can access the predicted clusters via 'predict()'.\n", "yellow")
+  insight::print_color("\n# You can access the predicted clusters via `predict()`.\n", "yellow")
   invisible(x)
 }
 
