@@ -49,6 +49,6 @@ model_parameters.ivFixed <- function(model,
     verbose = verbose,
     ...
   )
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
