@@ -36,7 +36,7 @@ model_parameters.mixor <- function(model,
     ...
   )
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
 
   out
 }
@@ -83,6 +83,6 @@ simulate_model.mixor <- function(model, iterations = 1000, effects = "all", ...)
   out <- .simulate_model(model, iterations, component = "conditional", effects = effects, ...)
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
