@@ -26,7 +26,7 @@ model_parameters.mvord <- function(model,
     p_adjust = p_adjust,
     ...
   )
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
@@ -89,6 +89,6 @@ simulate_model.mvord <- function(model, iterations = 1000, component = c("all",
   out <- .simulate_model(model, iterations, component = component, ...)
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
