@@ -101,13 +101,14 @@ model_parameters.stanreg <- function(model,
 
   if (effects != "fixed") {
     random_effect_levels <- which(
-      params$Effects %in% "random" & grepl("^(?!Sigma\\[)(.*)", params$Parameter, perl = TRUE)
+      params$Effects %in% "random" & !startsWith(params$Parameter, "Sigma[")
     )
     if (length(random_effect_levels) && isFALSE(group_level)) {
       params <- params[-random_effect_levels, , drop = FALSE]
     }
   }
 
+  ## TODO: can we use the regular pretty-name-formatting?
   params <- .add_pretty_names(params, model)
 
   # exponentiate coefficients and SE/CI, if requested
@@ -124,7 +125,7 @@ model_parameters.stanreg <- function(model,
   )
 
   attr(params, "parameter_info") <- insight::clean_parameters(model)
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(params) <- c("parameters_stan", "parameters_model", "see_parameters_model", class(params))
 
   params
@@ -174,7 +175,7 @@ model_parameters.stanmvreg <- function(model,
   params <- .add_pretty_names(params, model)
 
   attr(params, "ci") <- ci
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
